nxp-pac

Crates

git

Versions

lpc55s69_cm33_core0

Flavors

DcfgCcSocuPin

Struct DcfgCcSocuPin 

#[repr(transparent)]
pub struct DcfgCcSocuPin(pub u32);
With TZ-M, the part can be sold by level 1 customers (secure code developer) to level-2 customers who develops non-secure code only. - In this scenario, or easy of development, Level-I customer releases the part to always allow non-secure debug. - To allow level-2 customers to further seal the part DCFG_CC_SOCU_NS is used. - ROM will use this word to further restrict the debug access.

Tuple Fields

0: u32

Implementations

Source

impl DcfgCcSocuPin

pub const fn niden(&self) -> DcfgCcSocuPinNiden

Non Secure non-invasive debug enable

pub const fn set_niden(&mut self, val: DcfgCcSocuPinNiden)

Non Secure non-invasive debug enable

pub const fn dbgen(&self) -> DcfgCcSocuPinDbgen

Non Secure debug enable

pub const fn set_dbgen(&mut self, val: DcfgCcSocuPinDbgen)

Non Secure debug enable

pub const fn spniden(&self) -> DcfgCcSocuPinSpniden

Secure non-invasive debug enable

pub const fn set_spniden(&mut self, val: DcfgCcSocuPinSpniden)

Secure non-invasive debug enable

pub const fn spiden(&self) -> DcfgCcSocuPinSpiden

Secure invasive debug enable

pub const fn set_spiden(&mut self, val: DcfgCcSocuPinSpiden)

Secure invasive debug enable

pub const fn tapen(&self) -> DcfgCcSocuPinTapen

JTAG TAP enable

pub const fn set_tapen(&mut self, val: DcfgCcSocuPinTapen)

JTAG TAP enable

pub const fn cpu1_dbgen(&self) -> DcfgCcSocuPinCpu1Dbgen

CPU1 (Micro cortex M33) invasive debug enable

pub const fn set_cpu1_dbgen(&mut self, val: DcfgCcSocuPinCpu1Dbgen)

CPU1 (Micro cortex M33) invasive debug enable

pub const fn isp_cmd_en(&self) -> DcfgCcSocuPinIspCmdEn

ISP Boot Command enable

pub const fn set_isp_cmd_en(&mut self, val: DcfgCcSocuPinIspCmdEn)

ISP Boot Command enable

pub const fn fa_cmd_en(&self) -> DcfgCcSocuPinFaCmdEn

FA Command enable

pub const fn set_fa_cmd_en(&mut self, val: DcfgCcSocuPinFaCmdEn)

FA Command enable

pub const fn me_cmd_en(&self) -> DcfgCcSocuPinMeCmdEn

Flash Mass Erase Command enable

pub const fn set_me_cmd_en(&mut self, val: DcfgCcSocuPinMeCmdEn)

Flash Mass Erase Command enable

pub const fn cpu1_niden(&self) -> DcfgCcSocuPinCpu1Niden

CPU1 (Micro cortex M33) non-invasive debug enable

pub const fn set_cpu1_niden(&mut self, val: DcfgCcSocuPinCpu1Niden)

CPU1 (Micro cortex M33) non-invasive debug enable

pub const fn uuid_check(&self) -> bool

Enforce UUID match during Debug authentication.

pub const fn set_uuid_check(&mut self, val: bool)

Enforce UUID match during Debug authentication.

pub const fn inverse_value(&self) -> u16

inverse value of bits [15:0]

pub const fn set_inverse_value(&mut self, val: u16)

inverse value of bits [15:0]